
=====================  ====  =======  =======  ================================================================
Key                    Type  Options  Default  Description                                                     
=====================  ====  =======  =======  ================================================================
``key``                str   ..       ..       Unique key used to identify this plan                           
``drpqa_key``          str   ..       ..       Data reduction quality assessment method keyword                
``drpqa_clobber``      bool  ..       False    Overwrite any existing data-quality assessment reference files  
``bin_key``            str   ..       ..       Spatial binning method keyword                                  
``bin_clobber``        bool  ..       False    Overwrite any existing spatial binning reference files          
``continuum_key``      str   ..       ..       Stellar-continuum fitting method keyword                        
``continuum_clobber``  bool  ..       False    Overwrite any existing stellar-continuum fitting reference files
``elmom_key``          str   ..       ..       Emission-line moments measurement method keyword                
``elmom_clobber``      bool  ..       False    Overwrite any existing emission-line moments reference files    
``elfit_key``          str   ..       ..       Emission-line modeling method keyword                           
``elfit_clobber``      bool  ..       False    Overwrite any existing emission-line modeling reference files   
``spindex_key``        str   ..       ..       Spectral-index measurement method keyword                       
``spindex_clobber``    bool  ..       False    Overwrite any existing spectral-index reference files           
=====================  ====  =======  =======  ================================================================

